@@ -470,9 +470,6 @@ create_tree_view(int n, n_list_store *list, int tree)
 
   tview = gtk_tree_view_new_with_model(lstore);
 
-#if ! GTK_CHECK_VERSION(3, 14, 0)
-  gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(tview), TRUE);
-#endif
   gtk_tree_view_set_rubber_banding(GTK_TREE_VIEW(tview), TRUE);
   gtk_tree_view_set_grid_lines(GTK_TREE_VIEW(tview), GTK_TREE_VIEW_GRID_LINES_VERTICAL);
 
@@ -1113,17 +1110,9 @@ list_store_remove_selected_cb(GtkWidget *w, gpointer client_data)
     gtk_tree_view_set_cursor(GTK_TREE_VIEW(client_data), first_path, NULL, FALSE);
   }
 
-  g_list_foreach(selected, free_tree_path_cb, NULL);
-  g_list_free(selected);
+  g_list_free_full(selected, (GDestroyNotify) gtk_tree_path_free);
 }
 
-void
-free_tree_path_cb(gpointer data, gpointer user_data)
-{
-  gtk_tree_path_free(data);
-}
-
-
 void
 tree_store_selected_toggle_expand(GtkWidget *w)
 {
