@@ -648,7 +648,7 @@ gra2cairo_clip_region(struct gra2cairo_local *local, cairo_region_t *region)
 }
 
 static double
-gra2cairo_get_pixel_dot(struct objlist *obj, N_VALUE *inst, char **argv)
+gra2cairo_get_pixel_dot(char **argv)
 {
   int dpi;
 
@@ -679,7 +679,7 @@ gra2cairo_set_dpi(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, c
   _putobj(obj, "dpiy", inst, &dpi);
 
   local->pixel_dot_x =
-    local->pixel_dot_y = gra2cairo_get_pixel_dot(obj, inst, argv);
+    local->pixel_dot_y = gra2cairo_get_pixel_dot(argv);
 
   return 0;
 }
@@ -691,7 +691,7 @@ gra2cairo_set_dpi_x(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc,
 
   _getobj(obj, "_local", inst, &local);
 
-  local->pixel_dot_x = gra2cairo_get_pixel_dot(obj, inst, argv);
+  local->pixel_dot_x = gra2cairo_get_pixel_dot(argv);
 
   return 0;
 }
@@ -703,7 +703,7 @@ gra2cairo_set_dpi_y(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc,
 
   _getobj(obj, "_local", inst, &local);
 
-  local->pixel_dot_y = gra2cairo_get_pixel_dot(obj, inst, argv);
+  local->pixel_dot_y = gra2cairo_get_pixel_dot(argv);
 
   return 0;
 }
@@ -778,6 +778,26 @@ gra2cairo_get_compatible_font_info(const char *name)
   return &CompatibleFont[i];
 }
 
+int
+get_font_style(struct objlist *obj, N_VALUE *inst, const char *field, const char *font_field)
+{
+  int style;
+  struct compatible_font_info *compatible;
+  char *font;
+
+  _getobj(obj, font_field, inst, &font);
+  compatible = gra2cairo_get_compatible_font_info(font);
+  if (compatible && compatible->name && ! compatible->symbol) {
+    g_free(font);
+    font = g_strdup(compatible->name);
+    _putobj(obj, font_field, inst, font);
+    style = compatible->style;
+  } else {
+    _getobj(obj, field, inst, &style);
+  }
+  return style;
+}
+
 static struct fontmap *
 loadfont(char *fontalias, int font_style, int *symbol)
 {
