@@ -534,6 +534,10 @@ DialogButton(GtkWidget *parent, const char *title, const char *caption, struct n
   }
 
   gtk_window_set_resizable(GTK_WINDOW(dlg), FALSE);
+  if (parent) {
+    gtk_window_set_transient_for(GTK_WINDOW(dlg), GTK_WINDOW(parent));
+    gtk_window_set_modal(GTK_WINDOW(parent), TRUE);
+  }
 
   set_dialog_position(dlg, x, y);
   gtk_widget_show_all(dlg);
@@ -1085,16 +1089,7 @@ FileSelectionDialog(GtkWidget *parent, struct nGetOpenFileData *data)
   fname = get_filename_with_ext(data->init_file, data->ext);
   if (fname) {
     if (data->type == GTK_FILE_CHOOSER_ACTION_SAVE) {
-#if WINDOWS
-      char *tmp;
-      tmp = g_locale_from_utf8(fname, -1, NULL, NULL, NULL);
-      if (tmp) {
-	file_dialog_set_current_neme(dlg, tmp);
-	g_free(tmp);
-      }
-#else  /* WINDOWS */
       file_dialog_set_current_neme(dlg, fname);
-#endif	/* WINDOWS */
     } else {
       gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(dlg), fname);
     }
