@@ -1279,7 +1279,7 @@ free_markpixmap(void)
 static void
 create_icon(void)
 {
-  GList *tmp, *list = NULL;
+  GList *list = NULL;
   GdkPixbuf *pixbuf;
 
   pixbuf = gdk_pixbuf_new_from_resource(NGRAPH_SVG_ICON_FILE, NULL);
@@ -1300,13 +1300,7 @@ create_icon(void)
   if (list) {
     gtk_window_set_default_icon_list(list);
     gtk_window_set_icon_list(GTK_WINDOW(TopLevel), list);
-
-    tmp = list;
-    while (tmp) {
-      g_object_unref(tmp->data);
-      tmp = tmp->next;
-    }
-    g_list_free(list);
+    g_list_free_full(list, g_object_unref);
   }
 }
 
@@ -2267,11 +2261,7 @@ create_toplevel_window(void)
   int i;
   struct objlist *aobj;
   int x, y, width, height, w, h;
-#if GTK_CHECK_VERSION(3, 22, 0)
   GdkDisplay *disp;
-#else
-  GdkScreen *screen;
-#endif
   GtkWidget *popup;
   GtkClipboard *clip;
 
@@ -2280,7 +2270,6 @@ create_toplevel_window(void)
   init_action_widget_list();
   init_ngraph_app_struct();
 
-#if GTK_CHECK_VERSION(3, 22, 0)
   w = 800;
   h = 600;
   disp = gdk_display_get_default();
@@ -2296,11 +2285,6 @@ create_toplevel_window(void)
       h = rect.height;
     }
   }
-#else
-  screen = gdk_screen_get_default();
-  w = gdk_screen_get_width(screen);
-  h = gdk_screen_get_height(screen);
-#endif
 
   if (Menulocal.menux == DEFAULT_GEOMETRY)
     Menulocal.menux = w * 3 / 8;
@@ -2734,7 +2718,7 @@ int
 PutStderr(const char *s)
 {
   size_t len;
-  char *ustr, *arg[] = {NULL};
+  char *ustr;
 
   if (s == NULL)
     return 0;
@@ -2746,7 +2730,6 @@ PutStderr(const char *s)
   message_box(NULL, ustr, _("Error:"), RESPONS_ERROR);
   len = strlen(ustr);
   g_free(ustr);
-  UpdateAll2(arg, FALSE);
   return len + 1;
 }
 
@@ -2792,10 +2775,8 @@ int
 InputYN(const char *mes)
 {
   int ret;
-  char *arg[] = {NULL};
 
   ret = message_box(get_current_window(), mes, _("Question"), RESPONS_YESNO);
-  UpdateAll2(arg, FALSE);
   return (ret == IDYES) ? TRUE : FALSE;
 }
 
