@@ -10,6 +10,8 @@ struct ope_str {
 };
 
 static struct ope_str OpeStr[] = {
+  {"<<=", 3, MATH_OPERATOR_TYPE_BIT_SHIFT_L_ASSIGN},
+  {">>=", 3, MATH_OPERATOR_TYPE_BIT_SHIFT_R_ASSIGN},
   {":=", 2, MATH_OPERATOR_TYPE_ASSIGN},
   {">:", 2, MATH_OPERATOR_TYPE_GE},
   {">=", 2, MATH_OPERATOR_TYPE_GE},
@@ -33,6 +35,10 @@ static struct ope_str OpeStr[] = {
   {"\\=", 2, MATH_OPERATOR_TYPE_MOD_ASSIGN},
   {"^:", 2, MATH_OPERATOR_TYPE_POW_ASSIGN},
   {"^=", 2, MATH_OPERATOR_TYPE_POW_ASSIGN},
+  {"<<", 2, MATH_OPERATOR_TYPE_BIT_SHIFT_L},
+  {">>", 2, MATH_OPERATOR_TYPE_BIT_SHIFT_R},
+  {"&=", 2, MATH_OPERATOR_TYPE_BIT_AND_ASSIGN},
+  {"|=", 2, MATH_OPERATOR_TYPE_BIT_OR_ASSIGN},
   {"-", 1, MATH_OPERATOR_TYPE_MINUS},
   {"+", 1, MATH_OPERATOR_TYPE_PLUS},
   {"*", 1, MATH_OPERATOR_TYPE_MUL},
@@ -45,6 +51,9 @@ static struct ope_str OpeStr[] = {
   {"<", 1, MATH_OPERATOR_TYPE_LT},
   {"=", 1, MATH_OPERATOR_TYPE_EOEQ_ASSIGN},
   {";", 1, MATH_OPERATOR_TYPE_EOEQ},
+  {"&", 1, MATH_OPERATOR_TYPE_BIT_AND},
+  {"|", 1, MATH_OPERATOR_TYPE_BIT_OR},
+  {"~", 1, MATH_OPERATOR_TYPE_BIT_NOT},
 };
 
 static char OpeChar[256] = {
@@ -174,7 +183,7 @@ static char OpeChar[256] = {
   0,
   1,  /* | */
   0,
-  0,
+  1,  /* ~ */
   0,
   0,
   0,
