@@ -21,6 +21,8 @@
  *
  */
 
+#include "common.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <fcntl.h>
@@ -28,8 +30,6 @@
 #include <errno.h>
 #include <glib.h>
 
-#include "common.h"
-
 #include "object.h"
 #include "nstring.h"
 #include "ioutil.h"
@@ -261,13 +261,15 @@ make_backup(char *homedir, char *libdir, char *fil, FILE *fptmp)
 static char *
 replaceconfig_match(FILE *fp, FILE *fptmp, struct narray *iconf, struct narray *conf)
 {
-  char *s, *s2, *buf, *tok, *tok2, **data;
-  int out, len, len2, i, j, num, num2;
+  char *s, *s2, *buf, *tok2, **data;
+  int len, len2, i, j, num, num2;
 
   num = arraynum(conf);
   data = arraydata(conf);
 
   while (fgetline(fp, &buf) == 0) {
+    char *tok;
+    int out;
     if (buf[0]=='[') {
       return buf;
     }
@@ -576,7 +578,7 @@ copyconfig(void)
 {
   struct objlist *sys;
   char *libdir,*homedir,*buf;
-  char *libname,*homename,*bak;
+  char *libname,*homename;
   FILE *libfp,*homefp;
   int r;
   GStatBuf sbuf;
@@ -595,6 +597,7 @@ copyconfig(void)
   }
 
   if (findfilename(homedir,CONFSEP,CONF)) {
+    char *bak;
     if ((bak=getfilename(homedir,CONFSEP,CONFBAK))!=NULL) {
       if (findfilename(homedir,CONFSEP,CONFBAK)) g_unlink(bak);
       if ((homename=getfilename(homedir,CONFSEP,CONF))!=NULL) {
@@ -626,7 +629,6 @@ copyconfig(void)
     g_free(homename);
     fclose(homefp);
     g_free(libname);
-    fclose(libfp);
     return FALSE;
   }
   g_free(homename);
