@@ -18,7 +18,7 @@ union ngraph_val {
 static struct narray *
 allocate_iarray(ngraph_arg *arg)
 {
-  struct narray *array, *ptr;
+  struct narray *array;
   int i;
 
   if (arg == NULL) {
@@ -35,6 +35,7 @@ allocate_iarray(ngraph_arg *arg)
   }
 
   for (i = 0; i < arg->num; i++) {
+    struct narray *ptr;
     ptr = arrayadd(array, &arg->ary[i].i);
     if (ptr == NULL) {
       arrayfree(array);
@@ -48,7 +49,7 @@ allocate_iarray(ngraph_arg *arg)
 static struct narray *
 allocate_darray(ngraph_arg *arg)
 {
-  struct narray *array, *ptr;
+  struct narray *array;
   int i;
 
   if (arg == NULL) {
@@ -65,6 +66,7 @@ allocate_darray(ngraph_arg *arg)
   }
 
   for (i = 0; i < arg->num; i++) {
+    struct narray *ptr;
     ptr = arrayadd(array, &arg->ary[i].d);
     if (ptr == NULL) {
       arrayfree(array);
@@ -78,7 +80,7 @@ allocate_darray(ngraph_arg *arg)
 static struct narray *
 allocate_sarray(ngraph_arg *arg)
 {
-  struct narray *array, *ptr;
+  struct narray *array;
   int i;
 
   if (arg == NULL) {
@@ -95,6 +97,7 @@ allocate_sarray(ngraph_arg *arg)
   }
 
   for (i = 0; i < arg->num; i++) {
+    struct narray *ptr;
     ptr = arrayadd2(array, arg->ary[i].str);
     if (ptr == NULL) {
       arrayfree(array);
@@ -187,7 +190,7 @@ ngraph_object_put(struct objlist *obj, const char *vname, int id, ngraph_value *
 static const char **
 allocate_obj_arg(struct objlist *obj, const char *vname, ngraph_arg *arg)
 {
-  int i, n, num, is_a;
+  int i, num;
   const char *arglist;
   const char **ary;
 
@@ -212,8 +215,10 @@ allocate_obj_arg(struct objlist *obj, const char *vname, ngraph_arg *arg)
       ary[i] = arg->ary[i].str;
     }
   } else {
+    int n;
     n = 0;
     for (i = 0; arglist[i]; i++) {
+      int is_a;
       if (n >= num) {
 	break;
       }
@@ -267,7 +272,7 @@ allocate_obj_arg(struct objlist *obj, const char *vname, ngraph_arg *arg)
 static void
 free_obj_arg(const char **ary, struct objlist *obj, const char *vname, ngraph_arg *arg)
 {
-  int i, n, num, is_a;
+  int i, n, num;
   const char *arglist;
 
   num = arg->num;
@@ -282,6 +287,7 @@ free_obj_arg(const char **ary, struct objlist *obj, const char *vname, ngraph_ar
 
   n = 0;
   for (i = 0; arglist[i]; i++) {
+    int is_a;
     if (n >= num) {
       break;
     }
