@@ -24,6 +24,8 @@
 #ifndef OLEGEND_HEADER
 #define OLEGEND_HEADER
 
+#define ROTATE_MARK 0
+
 enum FLIP_DIRECTION {
   FLIP_DIRECTION_HORIZONTAL,
   FLIP_DIRECTION_VERTICAL,
@@ -40,5 +42,10 @@ void rotate(int px, int py, int angle, int *x, int *y);
 void flip(int pivot, enum FLIP_DIRECTION dir, int *x, int *y);
 int legendflip(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv);
 int put_color_for_backward_compatibility(struct objlist *obj, N_VALUE *inst, N_VALUE *rval,  int argc, char **argv);
+void draw_marker_mark(struct objlist *obj, N_VALUE *inst, int GC, int width, int headlen, int headwidth, int x0, int y0, double dx, double dy, int r, int g, int b, int a, int type);
+void draw_marker_bar(struct objlist *obj, N_VALUE *inst, int GC, int width, int headlen, int headwidth, int x0, int y0, double dx, double dy);
+void draw_marker_wave(struct objlist *obj, N_VALUE *inst, int GC, int width, int headlen, int headwidth, int x0, int y0, double dx, double dy, int errspl);
+int mark_flip(int dir, int type);
+int mark_rotate(int angle, int type);
 
 #endif
