@@ -104,7 +104,6 @@ markdraw(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   GRAview(GC,0,0,w*10000.0/zoom,h*10000.0/zoom,clip);
   GRAlinestyle(GC,snum,sdata,width,GRA_LINE_CAP_BUTT,GRA_LINE_JOIN_MITER,1000);
   GRAmark(GC,type,x,y,size,fr,fg,fb,fa,br,bg,bb,ba);
-  GRAaddlist(GC,obj,inst,(char *)argv[0],(char *)argv[1]);
   return 0;
 }
 
@@ -172,8 +171,6 @@ markrotate(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   px = *(int *) argv[4];
   py = *(int *) argv[5];
 
-  angle = *(int *) argv[2];
-
 #if MODIFY_MARK_TYPE
   _getobj(obj, "type", inst, &type);
   type = mark_rotate(angle, type)
@@ -234,7 +231,7 @@ markflip(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
 static int
 markzoom(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
 {
-  int i,x,y,size,refx,refy,width,snum,*sdata,preserve_width;
+  int x,y,size,refx,refy,width,snum,*sdata,preserve_width;
   double zoom, zoom_x, zoom_y;
   struct narray *style;
 
@@ -256,6 +253,7 @@ markzoom(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   y=(y-refy)*zoom_y+refy;
   size=size*zoom;
   if (! preserve_width) {
+    int i;
     width=width*zoom;
     for (i=0;i<snum;i++) sdata[i]=sdata[i]*zoom;
   }
