@@ -39,6 +39,7 @@
 #include "ioutil.h"
 #include "gra.h"
 #include "oroot.h"
+#include "odata.h"
 #include "odraw.h"
 #include "osystem.h"
 
@@ -250,13 +251,17 @@ gra_cache_init(struct gra_cache *cache, struct gra_info *info)
 static int *
 dup_cpar(const int *cpar)
 {
-  int n;
+  gsize n;
 
   n = cpar[0] + 1;
   if (n < 1) {
     n = 1;
   }
+#if GLIB_CHECK_VERSION(2, 68, 0)
+  return g_memdup2(cpar, n * sizeof(*cpar));
+#else
   return g_memdup(cpar, n * sizeof(*cpar));
+#endif
 }
 
 static int
@@ -693,10 +698,6 @@ static int
 mergestore(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
 {
   struct mergelocal *mergelocal;
-  char *file,*base,*date,*time;
-  int style;
-  char *buf;
-  char *argv2[2];
 
   g_free(rval->str);
   rval->str=NULL;
@@ -704,116 +705,21 @@ mergestore(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   if (mergelocal->endstore) {
     mergelocal->endstore=FALSE;
     return 1;
-  } else if (mergelocal->storefd==NULL) {
-    _getobj(obj,"file",inst,&file);
-    if (file==NULL) return 1;
-    style=3;
-    argv2[0]=(char *)&style;
-    argv2[1]=NULL;
-    if (_exeobj(obj,"date",inst,1,argv2)) return 1;
-    style=0;
-    argv2[0]=(char *)&style;
-    argv2[1]=NULL;
-    if (_exeobj(obj,"time",inst,1,argv2)) return 1;
-    _getobj(obj,"date",inst,&date);
-    if(date == NULL) {
-      date = "1-1-1970";
-    }
-    _getobj(obj,"time",inst,&time);
-    if(time == NULL) {
-      time = "00:00:00";
-    }
-    if ((base=getbasename(file))==NULL) return 1;
-    if ((mergelocal->storefd=nfopen(file,"rt"))==NULL) {
-      g_free(base);
-      return 1;
-    }
-    buf = g_strdup_printf("merge::load_data '%s' '%s %s' <<'[EOF]'", base, date, time);
-    g_free(base);
-    if (buf == NULL) {
-      fclose(mergelocal->storefd);
-      mergelocal->storefd=NULL;
-      return 1;
-    }
-    rval->str=buf;
-    return 0;
-  } else {
-    if (fgetline(mergelocal->storefd,&buf)!=0) {
-      fclose(mergelocal->storefd);
-      mergelocal->storefd=NULL;
-      buf = g_strdup("[EOF]\n");
-      if (buf == NULL) return 1;
-      mergelocal->endstore=TRUE;
-      rval->str=buf;
-      return 0;
-    } else {
-      rval->str=buf;
-      return 0;
-    }
   }
+  return store(obj, inst, rval, argc, argv, &mergelocal->endstore, &mergelocal->storefd);
 }
 
 static int
 mergeload(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
 {
-  char *s;
-  int len;
-  char *file,*fullname,*oldfile;
-  time_t ftime;
-  int mkdata;
-  struct utimbuf tm;
-
-  s=(char *)argv[2];
-  if ((file=getitok2(&s,&len," \t"))==NULL) return 1;
-  if ((fullname=getfullpath(file))==NULL) {
-    g_free(file);
-    return 1;
-  }
-  _getobj(obj,"file",inst,&oldfile);
-  g_free(oldfile);
-  _putobj(obj,"file",inst,fullname);
-  if (gettimeval(s,&ftime)) {
-    g_free(file);
-    return 1;
-  }
-  if (naccess(file,R_OK)!=0) mkdata=TRUE;
-  else {
-    char *mes;
-    if ((mes=g_malloc(strlen(file)+256))==NULL) {
-      g_free(file);
-      return 1;
-    }
-    sprintf(mes,"`%s' Overwrite existing file?",file);
-    mkdata=inputyn(mes);
-    g_free(mes);
-  }
-  if (mkdata) {
-    char buf[2];
-    FILE *fp;
-    if ((fp=nfopen(file,"wt"))==NULL) {
-      error2(obj,ERROPEN,file);
-      g_free(file);
-      return 1;
-    }
-    while (nread(stdinfd(),buf,1)==1) fputc(buf[0],fp);
-    fclose(fp);
-    tm.actime=ftime;
-    tm.modtime=ftime;
-    utime(file,&tm);
-  }
-  g_free(file);
-  return 0;
+  return load_file(obj, inst, rval, argc, argv);
 }
 
 static int
 mergestoredum(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
 {
   struct mergelocal *mergelocal;
-  char *file,*base,*date,*time;
-  int style;
   char *buf;
-  char *argv2[2];
-
   g_free(rval->str);
   rval->str=NULL;
   _getobj(obj,"_local",inst,&mergelocal);
@@ -821,27 +727,7 @@ mergestoredum(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **ar
     mergelocal->endstore=FALSE;
     return 1;
   }
-  _getobj(obj,"file",inst,&file);
-  if (file==NULL) return 1;
-  style=3;
-  argv2[0]=(char *)&style;
-  argv2[1]=NULL;
-  if (_exeobj(obj,"date",inst,1,argv2)) return 1;
-  style=0;
-  argv2[0]=(char *)&style;
-  argv2[1]=NULL;
-  if (_exeobj(obj,"time",inst,1,argv2)) return 1;
-  _getobj(obj,"date",inst,&date);
-  if(date == NULL) {
-    date = "1-1-1970";
-  }
-  _getobj(obj,"time",inst,&time);
-  if(time == NULL) {
-    time = "00:00:00";
-  }
-  if ((base=getbasename(file))==NULL) return 1;
-  buf = g_strdup_printf("merge::load_dummy '%s' '%s %s'\n", base, date, time);
-  g_free(base);
+  buf = store_dummy(obj, inst, argc, argv);
   if (buf == NULL) {
     return 1;
   }
@@ -853,20 +739,7 @@ mergestoredum(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **ar
 static int
 mergeloaddum(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
 {
-  char *s;
-  int len;
-  char *file,*fullname,*oldfile;
-
-  s=(char *)argv[2];
-  if ((file=getitok2(&s,&len," \t"))==NULL) return 1;
-  if ((fullname=getfullpath(file))==NULL) {
-    g_free(file);
-    return 1;
-  }
-  _getobj(obj,"file",inst,&oldfile);
-  g_free(oldfile);
-  _putobj(obj,"file",inst,fullname);
-  return 0;
+  return load_dummy(obj, inst, rval, argc, argv);
 }
 
 static int
@@ -1144,7 +1017,11 @@ merge_inst_dup(struct objlist *obj, N_VALUE *src, N_VALUE *dest)
   if (i < 0) {
     return 1;
   }
+#if GLIB_CHECK_VERSION(2, 68, 0)
+  dest[i].ptr = g_memdup2(src[i].ptr, sizeof(struct mergelocal));
+#else
   dest[i].ptr = g_memdup(src[i].ptr, sizeof(struct mergelocal));
+#endif
   /*   mergelocal->storefd may be NULL */
   if (dest[i].ptr == NULL) {
     return 1;
