@@ -52,6 +52,7 @@ static char *sherrorlist[]={
 
 struct shlocal {
   int lock;
+  int security;
   struct nshell *nshell;
 };
 
@@ -70,6 +71,7 @@ cmdinit(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   if ((nshell=newshell())==NULL) return 1;
   ngraphenvironment(nshell);
   shlocal->lock=0;
+  shlocal->security=FALSE;
   shlocal->nshell=nshell;
   return 0;
 }
@@ -106,7 +108,7 @@ cmdshell(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   struct narray *sarray;
   struct objlist *sys;
   char **sdata;
-  int i,snum;
+  int i,snum,security;
   int err;
   char *filename,*filename2;
   int fd;
@@ -136,6 +138,9 @@ cmdshell(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   err=1;
   filename=NULL;
 
+  security = get_security();
+  set_security(shlocal->security || security);
+
   sarray=(struct narray *)argv[2];
   snum=arraynum(sarray);
   sdata=arraydata(sarray);
@@ -210,6 +215,7 @@ errexit:
   ninterrupt = save_interrupt;
   sigaction(SIGINT, &oldact, NULL);
 #endif
+  set_security(security);
   shellrestorestdio(nshell);
 
   if (nshell->deleted) {
@@ -231,7 +237,10 @@ cmdsecurity(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv
 static int
 cmd_set_security(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
 {
-  set_security(TRUE);
+  struct shlocal *shlocal;
+
+  _getobj(obj, "_local", inst, &shlocal);
+  shlocal->security = TRUE;
   return 0;
 }
 
